@@ -30,8 +30,8 @@ import shutil
 
 from pymatgen.io.vaspio.vasp_output import Chgcar
 from pymatgen.io.vaspio.vasp_input import Potcar
-from pymatgen.util.io_utils import which
-from pymatgen.util.decorators import requires
+from monty.os.path import which
+from monty.dev import requires
 
 
 @requires(which("bader"),
@@ -178,4 +178,4 @@ class BaderAnalysis(object):
         structure = self.chgcar.structure
         charges = map(self.get_charge_transfer, xrange(len(structure)))
         structure.add_oxidation_state_by_site(charges)
-        return structure
\ No newline at end of file
+        return structure
