@@ -17,7 +17,7 @@ import collections
 import numpy as np
 
 from pymatgen.core.lattice import Lattice
-from pymatgen.core.periodic_table import Element, Specie, \
+from pymatgen.core.periodic_table import Element, Specie, DummySpecie,\
     get_el_sp
 from pymatgen.serializers.json_coders import MSONable
 from pymatgen.util.coord_utils import pbc_diff
@@ -269,8 +269,13 @@ class Site(collections.Mapping, collections.Hashable, MSONable):
         """
         atoms_n_occu = {}
         for sp_occu in d["species"]:
-            sp = Specie.from_dict(sp_occu) if "oxidation_state" in sp_occu \
-                else Element(sp_occu["element"])
+            if "oxidation_state" in sp_occu and Element.is_valid_symbol(
+                    sp_occu["element"]):
+                sp = Specie.from_dict(sp_occu)
+            elif "oxidation_state" in sp_occu:
+                sp = DummySpecie.from_dict(sp_occu)
+            else:
+                sp = Element(sp_occu["element"])
             atoms_n_occu[sp] = sp_occu["occu"]
         props = d.get("properties", None)
         return cls(atoms_n_occu, d["xyz"], properties=props)
@@ -525,8 +530,13 @@ class PeriodicSite(Site, MSONable):
         """
         atoms_n_occu = {}
         for sp_occu in d["species"]:
-            sp = Specie.from_dict(sp_occu) if "oxidation_state" in sp_occu \
-                else Element(sp_occu["element"])
+            if "oxidation_state" in sp_occu and Element.is_valid_symbol(
+                    sp_occu["element"]):
+                sp = Specie.from_dict(sp_occu)
+            elif "oxidation_state" in sp_occu:
+                sp = DummySpecie.from_dict(sp_occu)
+            else:
+                sp = Element(sp_occu["element"])
             atoms_n_occu[sp] = sp_occu["occu"]
         props = d.get("properties", None)
         lattice = lattice if lattice else Lattice.from_dict(d["lattice"])
