@@ -618,14 +618,18 @@ class MPStaticVaspInputSet(DictVaspInputSet):
         self.kpoints_settings.update({"kpoints_density": kpoints_density})
         self.sym_prec = sym_prec
 
-    def get_kpoints(self, structure):
+    def get_kpoints(self, structure, primitive_standard=False):
         """
         Get a KPOINTS file using the fully automated grid method. Uses
         Gamma centered meshes for hexagonal cells and Monk grids otherwise.
 
         Args:
             structure (Structure/IStructure): structure to get kpoints
+            primitive_standard (Bool): whether the input structure is
+            a primitive standardized cell
         """
+        if not primitive_standard:
+            structure=self.get_poscar(structure).structure
         self.kpoints_settings['grid_density'] = \
             self.kpoints_settings["kpoints_density"] * \
             structure.lattice.reciprocal_lattice.volume * \
