@@ -305,7 +305,7 @@ class PointGroupAnalyzer(object):
         """
         def not_on_axis(site):
             v = np.cross(site.coords, axis)
-            return np.linalg.norm(v) > self.tol
+            return np.linalg.norm(v) > 1e-3
 
         valid_sets = []
         origin_site, dist_el_sites = cluster_sites(self.centered_mol, self.tol)
@@ -514,3 +514,4 @@ def generate_full_symmops(symmops, tol):
                 return generate_full_symmops(symmops + [SymmOp(m)], tol)
 
     return symmops
+
